@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 __author__ = 'bee'
 from django.contrib.auth.models import User
-from .models import CourseSectionMid, UserCourseSection
+from .models import CourseSectionMid, UserCourseSection, UserCourse
 from .utils import get_user_live_data
 
 
@@ -51,3 +51,10 @@ def get_user_last_course_section(user, start_dt=None, end_dt=None):
     else:
         return None
 
+
+def get_current_user_course(user):
+    uc_list = UserCourse.objects.filter(user=user).order_by('-created_at')
+    if uc_list.exists():
+        return uc_list.first()
+    else:
+        return None
\ No newline at end of file
