@@ -341,7 +341,7 @@ class UserQuestionAnswerRecord(models.Model):
 
 
 class UserLive(models.Model):
-    provider_name = models.CharField(max_length=180)  # 平台商
+    provider_name = models.CharField(max_length=180, default=u'cc')  # 平台商
     cc_user_id = models.CharField(max_length=180, null=True)  # CC账号
     room_id = models.CharField(max_length=180, null=True)  # 直播间ID
     live_id = models.CharField(max_length=180, null=True)  # 直播ID
@@ -367,7 +367,7 @@ class UserLive(models.Model):
         permissions = (
             ('view_all_userlives', '可以查看所有学生的录播'),
             ('view_teach_userlives', '可以查看所教的学生的录播'),
-            ('view_child_userlives', '可以查看亲自学生的录播'),
+            ('view_child_userlives', '可以查看亲子学生的录播'),
         )
 
     def __unicode__(self):
