@@ -18,3 +18,7 @@ user_live_delete =  Signal(providing_args=["user_live"])
 
 # 笔记创建的信号
 section_note_created = Signal(providing_args=["user_section_note_id"])
+
+
+# 直播评论后发出的信号
+user_live_comment = Signal(providing_args=['user_live', 'comment_user'])
\ No newline at end of file
