@@ -31,12 +31,20 @@ def get_video_provider_name():
     return settings.COURSE_VIDEO_PROVIDER_NAME
 
 
-# 点播视频播放地址
+# CC点播视频播放地址
 @register.filter
 def get_video_src(video_id):
     vid = video_id.__str__()
     return "https://p.bokecc.com/playhtml.bo?vid=" + vid + "&siteid=" + settings.COURSE_CC_USERID + "&autoStart=false&playerid=" + settings.COURSE_CC_PLAYERID + "&playertype=1"
 
+# 七牛云视频播放地址
+@register.filter
+def get_qiniu_video_src(file_name):
+    if file_name:
+        return "http://" + settings.QINIU_DOMAIN + "/" + file_name
+    else:
+        return ""
+
 
 # 用户是否学了此课程
 @register.simple_tag
@@ -115,7 +123,7 @@ def next_user_course_section(ucs):
     return next_ucs
 
 
-# 学生下一个能学的课件
+# 学生的答案
 @register.simple_tag
 def get_user_question_answer(question,user):
     return UserQuestionAnswerRecord.get_user_question_answer_options(question,user)
