@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-import json, os, random
+import json, os, random,datetime
 from django.forms.models import model_to_dict
 from django.shortcuts import render
 from dss.Serializer import serializer
@@ -386,8 +386,8 @@ def prepare_live_video_page_data(live_video_id):
         return
 
 
-def live_video_detail(request, live_video_id):
-    user_live = UserLive.objects.get(record_video_id=live_video_id)
+def live_video_detail(request, user_live_id):
+    user_live = UserLive.objects.get(pk=user_live_id)
     comments = user_live.userlivecomment_set.order_by('-submit_date')
 
     if request.method == "POST":
@@ -403,15 +403,14 @@ def live_video_detail(request, live_video_id):
         comment_form = UserLiveCommentForm()
 
     return render(request, 'bee_django_course/live/live_video_detail.html', context={
-        'record_video_id': live_video_id,
         'user_live': user_live,
         'comments': comments,
         'comment_form': comment_form,
     })
 
 
-def user_live_video_detail(request, live_video_id):
-    user_live = UserLive.objects.get(record_video_id=live_video_id)
+def user_live_video_detail(request, user_live_id):
+    user_live = UserLive.objects.get(pk=user_live_id)
     comments = user_live.userlivecomment_set.order_by('-submit_date')
 
     if request.method == "POST":
@@ -423,12 +422,11 @@ def user_live_video_detail(request, live_video_id):
             comment.save()
             signals.user_live_comment.send(sender=UserLiveComment, user_live=user_live, comment_user=request.user)
             return redirect(
-                reverse('bee_django_course:user_live_video_detail', kwargs={'live_video_id': live_video_id}))
+                reverse('bee_django_course:user_live_video_detail', kwargs={'user_live_id': user_live_id}))
     else:
         comment_form = UserLiveCommentForm()
 
     return render(request, 'bee_django_course/user/live_video_detail.html', context={
-        'record_video_id': live_video_id,
         'user_live': user_live,
         'comments': comments,
         'comment_form': comment_form,
@@ -565,25 +563,6 @@ def uptoken(request):
     })
 
 
-def add_video_to_part(request, part_id):
-    if request.method == "POST":
-        file_name = request.POST.get('file_name')
-        try:
-            part = get_object_or_404(Part, pk=part_id)
-            video_count = part.video_set.all().count() + 1
-            part.video_set.create(file_name=file_name, number=video_count)
-
-            return JsonResponse(data={
-                'rc': 0,
-                'message': '创建成功'
-            })
-        except Part.DoesNotExist:
-            return JsonResponse(data={
-                'rc': -1,
-                'message': '未找到对应小节'
-            })
-
-
 
 # 查看所有的学生录播
 @method_decorator(cls_decorator(cls_name='LiveList'), name='dispatch')
@@ -1293,6 +1272,7 @@ def save_cc_live(userId, roomId, liveId, stopStatus, recordStatus, recordVideoId
     else:
         cclive = UserLive()
         cclive.status = 1
+        cclive.provider_name = u'cc'
         cclive.stop_status = stopStatus
 
     cclive.cc_user_id = userId
@@ -1362,16 +1342,7 @@ def cc_live_finished_callback(request):
             user = cc_live.user
             refreshed_cc_live = UserLive.objects.get(pk=cc_live.pk)
             timedelta = (refreshed_cc_live.end_time - refreshed_cc_live.start_time).seconds
-            coin_multiple = 0
-            if timedelta >= 60 and user:
-                # 更新课件学习时间
-                user_course_section = get_user_last_course_section(user)
-                if user_course_section:
-                    user_course_section.update_work_time(timedelta / 60)
-
-                coin_multiple = save_coin_multiple(cc_live)
-
-                signals.live_callback_finished.send(sender=UserLive, user_live=cc_live, coin_multiple=coin_multiple)
+            live_finish(cc_live, timedelta)
 
             cc_live.call_count += 1
             cc_live.save()
@@ -1433,15 +1404,15 @@ class LivePlayLogs(TemplateView):
             # return redirect(reverse_lazy('bee_django_crm:preuser_application_update_preuser', kwargs={'pk': preuser.id}))
 
 
-def save_coin_multiple(cc_live):
+def save_coin_multiple(userlive):
     coin_multiple = 1
     r = random.randint(1, 1000)
     if r >= 980:
         coin_multiple = 3
     elif r >= 900:
         coin_multiple = 2
-    cc_live.coin_multiple = coin_multiple
-    cc_live.save()
+    userlive.coin_multiple = coin_multiple
+    userlive.save()
     return coin_multiple
 
 
@@ -1883,3 +1854,49 @@ def weixin_ucs_detail(request, ucs_id):
 
 def test_video(request):
     return render(request, 'bee_django_course/test_video.html')
+
+# 直播转码完成后的一系列操作：更新课件进度，发送信号
+def live_finish(userlive,timedelta=None):
+    if not timedelta:
+        timedelta=userlive.duration
+    if timedelta<60:
+        return
+
+    if not userlive.user:
+        return
+
+    # 更新课件学习时间
+    user_course_section = get_user_last_course_section(userlive.user)
+    if user_course_section:
+        user_course_section.update_work_time(timedelta / 60)
+    coin_multiple = save_coin_multiple(userlive)
+    signals.live_callback_finished.send(sender=UserLive, user_live=userlive, coin_multiple=coin_multiple)
+    return
+
+
+@csrf_exempt
+def tencent_live_callback(request):
+    # {"appid":1256935119,"channel_id":"aa","duration":3,"end_time":1562658284,"end_time_usec":453420,"event_type":100,"file_format":"mp4","file_id":"5285890791305792056","file_size":420382,"media_start_time":3801,"record_bps":0,"record_file_id":"5285890791305792056","start_time":1562658283,"start_time_usec":375858,"stream_id":"aa","stream_param":"txSecret=e939142722088dc59849bb82fc4d0fd1&txTime=5D24B9FF","task_id":"18288319047887901972","video_id":"1256935119_55156dda6162403abd8860da89d07ab6","video_url":"http://1256935119.vod2.myqcloud.com/8f802c2cvodcq1256935119/b3d83b505285890791305792056/f0.mp4"}
+    print("tencent_live_callback: ")
+
+    print request.body
+    username=request.body["stream_id"]
+    video_url=request.body["video_url"]
+    start_time=request.body["start_time"]
+    end_time=request.body["end_time"]
+    duration=request.body["duration"]
+
+    user=User.objects.get(username=username)
+    userlive=UserLive()
+    userlive.provider_name="tencent"
+    userlive.replay_url=video_url
+    userlive.start_time=datetime.datetime.fromtimestamp(start_time)
+    userlive.end_time=datetime.datetime.fromtimestamp(end_time)
+    userlive.user=user
+    userlive.duration=duration
+    userlive.status=1
+    userlive.save()
+    live_finish(userlive)
+    return JsonResponse({
+        "code": 0,
+    })
